<?php

namespace Drp\IOEngage;

use Drp\IOEngage\Exceptions\BadRequest;
use Drp\IOEngage\Exceptions\NoContent;
use Exception;
use Illuminate\Http\Client\Response as ClientResponse;

class Response
{
    public static function handle(ClientResponse $response): array
    {
        if (static::hasNoContent($response)) {
            throw new NoContent();
        }

        if (static::isSuccessful($response) === false) {
            return static::handleRequestError($response);
        }

        $responseBody = (string) $response->getBody();

        return json_decode($responseBody, true) ?: $responseBody;
    }

    private static function isSuccessful(ClientResponse $response): bool
    {
        if ($response === false) {
            return false;
        }

        return (int) substr($response->getStatusCode(), 0, 1) === 2;
    }

    private static function hasNoContent(ClientResponse $response): bool
    {
        if ($response === false) {
            return false;
        }

        return (int) $response->getStatusCode() === 204;
    }

    private static function handleRequestError(ClientResponse $response): void
    {
        if ($response->status() === 400) {
            throw new BadRequest((string) $response->body());
        }

        throw new Exception((string) $response->body());
    }
}
