<?php

namespace Drp\IOEngage;

use Carbon\Carbon;
use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Support\Arr;

class Token implements Arrayable
{
    /** @var string|null */
    public $accessToken;

    /** @var string|null */
    public $tokenType;

    /** @var int|null */
    public $expiresAt;

    public function __construct(array $attributes)
    {
        $this->accessToken = Arr::get($attributes, 'access_token');
        $this->tokenType = Arr::get($attributes, 'token_type');
        $this->setExpiresAt($attributes);
    }

    public function isInvalid(): bool
    {
        return $this->accessToken === null || $this->hasExpired();
    }

    public function hasExpired(): bool
    {
        if ($this->expiresAt === null) {
            return true;
        }

        return Carbon::createFromTimestamp($this->expiresAt) <= Carbon::now();
    }

    public function toArray(): array
    {
        return [
            'access_token' => $this->accessToken,
            'token_type' => $this->tokenType,
            'expires_at' => $this->expiresAt,
        ];
    }

    private function setExpiresAt(array $attributes): void
    {
        $expiresIn = Arr::get($attributes, 'expires_in');

        $this->expiresAt = null;

        if ($expiresIn === null) {
            return;
        }

        $this->expiresAt = now()->addSeconds($expiresIn)->timestamp;
    }
}
