<?php

namespace Drp\IOEngage\Tests\Feature;

use Drp\IOEngage\DelegatesResults;
use Drp\IOEngage\Facades\Token;
use Drp\IOEngage\IOEngage;
use Drp\IOEngage\Tests\TestCase;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Http;

class DelegatesTest extends TestCase
{
    /** @test **/
    public function handles_successful_response()
    {
        $response = File::get(__DIR__ . '/../responses/successfulDelegates.json');

        Http::fake([
            'WUKA00021171?Country=GB' => Http::response($response)
        ]);

        Token::fake();

        $results = (new IOEngage())->delegates('WUKA00021171');

        $this->assertInstanceOf(DelegatesResults::class, $results);
        $this->assertSame(1, $results->validCount);

        $this->assertInstanceOf(Collection::class, $results->validDelegates);
        $this->assertCount(1, $results->validDelegates);
    }

    /** @test **/
    public function handles_successful_response_that_has_invalid_delegates()
    {
        $response = File::get(__DIR__ . '/../responses/successfulDelegatesWithInvalidDelegates.json');

        Http::fake([
            'WUKA00021171,WUKA0002117A?Country=GB' => Http::response($response)
        ]);

        Token::fake();

        $results = (new IOEngage())->delegates(['WUKA00021171', 'WUKA0002117A']);

        $this->assertInstanceOf(DelegatesResults::class, $results);
        $this->assertSame(1, $results->validCount);
        $this->assertInstanceOf(Collection::class, $results->validDelegates);
        $this->assertCount(1, $results->validDelegates);

        $this->assertSame(1, $results->invalidCount);
        $this->assertInstanceOf(Collection::class, $results->invalidDelegates);
        $this->assertCount(1, $results->invalidDelegates);
    }

    /** @test **/
    public function handles_no_content_response()
    {
        Http::fake([
            'WUKA00021171?Country=GB' => Http::response(null, 204),
        ]);

        Token::fake();

        $results = (new IOEngage())->delegates('WUKA00021171');

        $this->assertInstanceOf(DelegatesResults::class, $results);
        $this->assertSame(0, $results->validCount);
        $this->assertSame(0, $results->invalidCount);
        $this->assertInstanceOf(Collection::class, $results->validDelegates);
        $this->assertInstanceOf(Collection::class, $results->invalidDelegates);
    }
}
