<?php

namespace Drp\IOEngage\Tests\Feature;

use Drp\IOEngage\Facades\Token;
use Drp\IOEngage\IOEngage;
use Drp\IOEngage\Resources\Delegate;
use Drp\IOEngage\SearchResults;
use Drp\IOEngage\Tests\TestCase;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Http;

class SearchTest extends TestCase
{
    /** @test **/
    public function handles_successful_response()
    {
        $response = File::get(__DIR__ . '/../responses/successfulSearch.json');

        Http::fake([
            'search?Country=GB&PerPage=10&Page=1&FirstName=Dan' => Http::response($response)
        ]);

        Token::fake();

        $results = (new IOEngage())->search(['first_name' => 'Dan']);

        $this->assertInstanceOf(SearchResults::class, $results);
        $this->assertSame(10, $results->perPage);
        $this->assertSame(1, $results->currentPage);
        $this->assertSame(20, $results->totalPages);
        $this->assertSame(200, $results->totalResults);

        $this->assertCount(10, $results->delegates);
        $this->assertInstanceOf(Collection::class, $results->delegates);
        $this->assertInstanceOf(Delegate::class, $results->delegates->first());
    }

    /** @test **/
    public function handles_no_content_response()
    {
        Http::fake([
            'search?Country=GB&PerPage=10&Page=1&FirstName=Dan' => Http::response(null, 204),
        ]);

        Token::fake();

        $results = (new IOEngage())->search(['first_name' => 'Dan']);

        $this->assertInstanceOf(SearchResults::class, $results);
        $this->assertSame(0, $results->perPage);
        $this->assertSame(0, $results->currentPage);
        $this->assertSame(0, $results->totalPages);
        $this->assertSame(0, $results->totalResults);

        $this->assertCount(0, $results->delegates);
        $this->assertInstanceOf(Collection::class, $results->delegates);
    }
}
