<?php

namespace Drp\IOEngage\Tests\Feature;

use Carbon\Carbon;
use Drp\IOEngage\Facades\Token;
use Drp\IOEngage\Tests\TestCase;
use Illuminate\Support\Facades\Http;

class TokenTest extends TestCase
{
    /** @test **/
    public function can_get_fresh_token_if_missing()
    {
        Http::fake([
            config('ioengage.endpoints.token') => Http::response([
                'access_token' => 'A_VERY_REAL_TOKEN',
                'token_type' => 'CLIENT_CREDENTIALS',
                'expires_in' => 36400,
            ], 200),
        ]);

        $this->assertNull(cache('ioengage_token'));

        $token = Token::get();

        $this->assertSame($token->toArray(), cache('ioengage_token'));
    }

    /** @test **/
    public function can_get_fresh_token_if_out_of_date()
    {
        cache()->set('ioengage_token', [
            'access_token' => 'A_VERY_REAL_TOKEN',
            'token_type' => 'CLIENT_CREDENTIALS',
            'expires_at' => Carbon::parse('7th Jan 2021 10:00:00')->timestamp,
        ]);

        Carbon::setTestNow('7th Jan 2021 10:05:00');

        Http::fake([
            config('ioengage.endpoints.token') => Http::response([
                'access_token' => 'A_VERY_REAL_TOKEN',
                'token_type' => 'CLIENT_CREDENTIALS',
                'expires_in' => 43200,
            ], 200),
        ]);

        Token::get();

        $this->assertSame([
            'access_token' => 'A_VERY_REAL_TOKEN',
            'token_type' => 'CLIENT_CREDENTIALS',
            'expires_at' => Carbon::parse('7th Jan 2021 22:05:00')->timestamp,
        ], cache('ioengage_token'));
    }
}
