<?php

namespace Drp\IOEngage\Tests\Unit;

use Drp\IOEngage\SearchParameters;
use Drp\IOEngage\Tests\TestCase;

class SearchParametersTest extends TestCase
{
    /** @test **/
    public function can_make_search_parameters()
    {
        $parameters = SearchParameters::make([
            'first_name' => 'Lee',
            'last_name' => 'Pownall',
            'name' => 'Lee Pownall',
            'email' => 'lee@example.com',
            'job_title' => 'Developer',
            'identifier' => 'LP34343',
            'company' => 'drpg',
            'line_1' => '212 Ikon Estate',
            'line_2' => 'Droitwich Road',
            'city' => 'Kidderminster',
            'country' => 'GB',
            'postcode' => 'DY10 4EU',
        ]);

        $expected = [
            'Country' => 'GB',
            'PerPage' => '10',
            'Page' => '1',
            'FirstName' => 'Lee',
            'LastName' => 'Pownall',
            'Name' => 'Lee Pownall',
            'Email' => 'lee@example.com',
            'JobTitle' => 'Developer',
            'OneKeyId' => 'LP34343',
            'Company' => 'drpg',
            'Line1' => '212 Ikon Estate',
            'Line2' => 'Droitwich Road',
            'City' => 'Kidderminster',
            'Postcode' => 'DY10 4EU',
        ];

        $this->assertSame($expected, $parameters);
    }

    /** @test **/
    public function filters_out_empty_parameters()
    {
        $parameters = SearchParameters::make([
            'first_name' => 'Lee',
            'last_name' => 'Pownall',
            'country' => 'GB',
        ]);

        $expected = [
            'Country' => 'GB',
            'PerPage' => '10',
            'Page' => '1',
            'FirstName' => 'Lee',
            'LastName' => 'Pownall',
        ];

        $this->assertSame($expected, $parameters);
    }

    /** @test **/
    public function country_defaults_to_GB()
    {
        $parameters = SearchParameters::make([]);

        $expected = [
            'Country' => 'GB',
            'PerPage' => '10',
            'Page' => '1',
        ];

        $this->assertSame($expected, $parameters);
    }

    /** @test **/
    public function can_specify()
    {
        $parameters = SearchParameters::make(
            ['first_name' => 'Lee'],
            5,
            20
        );

        $expected = [
            'Country' => 'GB',
            'PerPage' => '20',
            'Page' => '5',
            'FirstName' => 'Lee',
        ];

        $this->assertSame($expected, $parameters);
    }
}
